---
Summary: Allow collections to be added as 'tags' field in card
Status: Done
---

# Description

When a `tags` or `collections` field is present, it should also be added to those collections for the sake of `sbl` and other commands.

If there is a property styled field or a header style field, it should accept one tag per line, starting (following whitespace trim) with `-` ('bullet-point list style')

# Examples

### Property

```miid
---
Summary: Example
Tags:
    - tag1
    - tag2
---
```

### Header

```md
---
Summary: Example 2
---

# Tags

-   tag1
-   tag2
```

# Cucumber

**GIVEN** a `tags` or `collection` field
**WHEN** `sbl` is run with one of its members as the collection
**THEN** the card is shown
